# oktagon-python package
This python package is a tiny utility for verifying & decoding OKTA tokens in python backend services.

For more details please see following [guide](https://github.com/madedotcom/oktagon/docs/oktagon_integration.md)
